@@ -1,4 +1,4 @@
-__version__ = "0.6.0"
+__version__ = "0.6.1"
 
 __release_notes__ = {
     # "0.1.6": {
@@ -21,13 +21,13 @@ __release_notes__ = {
     #
     #        ],
     #    },
-    "0.6.0": {
+    "0.6.1": {
         "STATUS": [
         ],
         "A2P2": [
-            "Read Extra_informations from last Aspro2 OBXML"
         ],
         "VLTI": [
+            "Updated configuration for ESO P111",
         ],
         "CHARA": [
         ],
@@ -43,6 +43,12 @@ __release_notes__ = {
             "Complete test suite with real p2 submission",
             "Try to read OB in P2 and send them back to Aspro2 as a new obs",
         ],
+    },"0.6.0": {
+        "STATUS": [
+        ],
+        "A2P2": [
+            "Read Extra_informations from last Aspro2 OBXML"
+        ],
     },"0.5.3": {
         "STATUS": [
         ],
