@@ -29,6 +29,10 @@ class VltiInstrument(Instrument):
         self.rangeTable = None
         self.ditTable = None
 
+        # warnings
+        self.warnings = []
+        self.errors = []
+
     def get(self, obj, fieldname, defaultvalue):
         if fieldname in obj._fields:
             return getattr(obj, fieldname)
@@ -98,8 +102,9 @@ class VltiInstrument(Instrument):
         self.checkOB(ob, p2container)
 
         # refresh and select last created element tree
-        self.ui.updateTree(p2container.run, p2container.containerId)
-        self.ui.selectTreeItem(p2container.containerId)
+        ui.updateTree(p2container.run, p2container.containerId)
+        ui.selectTreeItem(p2container.containerId)
+        ui.addToLog("OB submitted! Please check logs and fix last details on P2 web.")
 
     def getCoords(self, target, requirePrecision=True):
         """
@@ -216,7 +221,6 @@ class VltiInstrument(Instrument):
         # if spec == "LOW":
         #    spec="HIGH"
         ditTable = self.getDitTable()
-        version = ditTable["VERSION"]
         mags = ditTable["AT"][spec][pol]['MAG']
         dits = ditTable["AT"][spec][pol]['DIT']
         if dualFeed:
@@ -237,8 +241,7 @@ class VltiInstrument(Instrument):
             kmax = max(kmax, mags[i + 1] + dK)
 
         if showWarning:
-            self.ui.ShowWarningMessage(
-                f"According to the template manual {version} :\n   K mag ({K})  is out of ranges [{kmin},{kmax}]\n for this mode ( ∆K={dK} tel={tel}, spec={spec}, pol={pol}, dualFeed={dualFeed}) \n  for target '{targetName}'")
+            self.warnings.append(f"K mag ({K})  is out of range [{kmin},{kmax}]\n mode ( ∆K={dK} tel={tel}, spec={spec}, pol={pol}, dualFeed={dualFeed}) \n  for target '{targetName}'")
 
         # always return a value to avoid unsupported operations
         if K < kmin:
@@ -282,7 +285,6 @@ class VltiInstrument(Instrument):
             return value >= rangeTable[_tpl][key]['min'] and \
                 value <= rangeTable[_tpl][key]['max']
         if 'list' in rangeTable[_tpl][key].keys():
-            print(f"Searching {value} in {rangeTable[_tpl][key]['list']}")
             #
             # hack set to check for coordinates convention define by p2
             # vlue will be checked by p2 later...
